pub struct Camera { /* private fields */ }Expand description
A 2D camera that can be zoomed and panned.
Implementations
Sourceimpl PanZoomCamera2d
impl PanZoomCamera2d
Sourcepub fn new(eye: Vec2, zoom: f32) -> PanZoomCamera2d
pub fn new(eye: Vec2, zoom: f32) -> PanZoomCamera2d
Create a new arc-ball camera.
Sourcepub fn set_at(&mut self, at: Vec2)
pub fn set_at(&mut self, at: Vec2)
Get a mutable reference to the point the camera is looking at.
Sourcepub fn set_zoom_step(&mut self, new_zoom_step: f32)
pub fn set_zoom_step(&mut self, new_zoom_step: f32)
Sets the zoom step of the camera.
Sourcepub fn look_at(&mut self, at: Vec2, zoom: f32)
pub fn look_at(&mut self, at: Vec2, zoom: f32)
Move the camera such that it is centered on a specific point.
The button used to drag the PanZoomCamera2d camera.
Set the button used to drag the PanZoomCamera2d camera. Use None to disable dragging.
Sourcepub fn drag_modifier(&self) -> Option<Modifiers>
pub fn drag_modifier(&self) -> Option<Modifiers>
The modifier used to drag the PanZoomCamera2d camera.
Sourcepub fn rebind_drag_modifier(&mut self, new_modifier: Option<Modifiers>)
pub fn rebind_drag_modifier(&mut self, new_modifier: Option<Modifiers>)
Set the modifier used to drag the PanZoomCamera2d camera.
Sourcepub fn zoom_modifier(&self) -> Option<Modifiers>
pub fn zoom_modifier(&self) -> Option<Modifiers>
The modifier used to zoom the PanZoomCamera2d camera.
Sourcepub fn rebind_zoom_modifier(&mut self, new_modifier: Option<Modifiers>)
pub fn rebind_zoom_modifier(&mut self, new_modifier: Option<Modifiers>)
Set the modifier used to zoom the PanZoomCamera2d camera.